# coding: utf-8
# **************************************************************************
# *
# * Authors:     Roberto Marabini (roberto@cnb.csic.es)
# *
# * L'Institut de genetique et de biologie moleculaire et cellulaire (IGBMC)
# *
# * This program is free software; you can redistribute it and/or modify
# * it under the terms of the GNU General Public License as published by
# * the Free Software Foundation; either version 2 of the License, or
# * (at your option) any later version.
# *
# * This program is distributed in the hope that it will be useful,
# * but WITHOUT ANY WARRANTY; without even the implied warranty of
# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# * GNU General Public License for more details.
# *
# * You should have received a copy of the GNU General Public License
# * along with this program; if not, write to the Free Software
# * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
# * 02111-1307  USA
# *
# *  All comments concerning this program package may be sent to the
# *  e-mail address 'scipion@cnb.csic.es'
# *
# **************************************************************************
"""
@Article{Goddard2018,
   Author="Goddard, T. D.  and Huang, C. C.  and Meng, E. C.  and Pettersen, E. F.  and Couch, G. S.  and Morris, J. H.  and Ferrin, T. E. ",
   Title="{{U}{C}{S}{F} {C}himera{X}: {M}eeting modern challenges in visualization and analysis}",
   Journal="Protein Sci.",
   Year="2018",
   Volume="27",
   Number="1",
   Pages="14--25",
   Month="01",
   doi = "https://doi.org/10.1002/pro.3235",
   url = "https://onlinelibrary.wiley.com/doi/full/10.1002/pro.3235"
}
@Article{Alphafold2021,
   Author="Tunyasuvunakool, K.  and Adler, J.  and Wu, Z.  and Green, T.  and Zielinski, M.  and Žídek, A.  and Bridgland, A.  and Cowie, A.  and Meyer, C.  and Laydon, A.  and Velankar, S.  and Kleywegt, G. J.  and Bateman, A.  and Evans, R.  and Pritzel, A.  and Figurnov, M.  and Ronneberger, O.  and Bates, R.  and Kohl, S. A. A.  and Potapenko, A.  and Ballard, A. J.  and Romera-Paredes, B.  and Nikolov, S.  and Jain, R.  and Clancy, E.  and Reiman, D.  and Petersen, S.  and Senior, A. W.  and Kavukcuoglu, K.  and Birney, E.  and Kohli, P.  and Jumper, J.  and Hassabis, D. ",
   Title="{{H}ighly accurate protein structure prediction for the human proteome}",
   Journal="Nature",
   Year="2021",
   Volume="596",
   Number="7873",
   Pages="590--596",
   Month="08"
}
"""
